document.addEventListener('DOMContentLoaded', () => {
  // Update parameter values display
  const parameters = document.querySelectorAll('.parameter input[type="range"]');
  parameters.forEach(param => {
    const valueDisplay = param.nextElementSibling;
    valueDisplay.textContent = param.value;
    
    param.addEventListener('input', (e) => {
      valueDisplay.textContent = e.target.value;
    });
  });

  // Toggle attention options visibility
  const modelTypeSelect = document.getElementById('modelType');
  const attentionOptions = document.getElementById('attentionOptions');
  
  modelTypeSelect.addEventListener('change', () => {
    attentionOptions.classList.toggle('hidden', modelTypeSelect.value !== 'attention');
  });

  // Run experiment button handler
  const runButton = document.getElementById('runExperiment');
  runButton.addEventListener('click', async () => {
    runButton.disabled = true;
    runButton.textContent = 'Running...';
    
    try {
      // Simulate experiment running
      await simulateExperiment();
      document.getElementById('visualization').classList.remove('hidden');
      updateResults();
    } catch (error) {
      console.error('Experiment failed:', error);
      alert('Experiment failed. Please try again.');
    } finally {
      runButton.disabled = false;
      runButton.textContent = 'Run Experiment';
    }
  });
});

async function simulateExperiment() {
  return new Promise(resolve => setTimeout(resolve, 2000));
}

function updateResults() {
  // Update metrics
  document.getElementById('aucValue').textContent = '0.892';
  document.getElementById('ksValue').textContent = '0.764';
  document.getElementById('logLossValue').textContent = '0.328';
  
  // Draw loss chart
  const ctx = document.getElementById('lossChart').getContext('2d');
  const gradient = ctx.createLinearGradient(0, 0, 0, 400);
  gradient.addColorStop(0, 'rgba(52, 152, 219, 0.5)');
  gradient.addColorStop(1, 'rgba(52, 152, 219, 0.1)');
  
  ctx.beginPath();
  ctx.moveTo(0, 400);
  
  // Simulate loss curve
  for (let x = 0; x < 400; x++) {
    const y = 400 - (Math.exp(-x/100) * 300);
    ctx.lineTo(x, y);
  }
  
  ctx.lineTo(400, 400);
  ctx.fillStyle = gradient;
  ctx.strokeStyle = '#3498db';
  ctx.lineWidth = 2;
  ctx.fill();
  ctx.stroke();
}
